summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/drivers/peyper.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/drivers/peyper.cpp')
-rw-r--r--src/mame/drivers/peyper.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mame/drivers/peyper.cpp b/src/mame/drivers/peyper.cpp
index 81321008e57..b6007e3385b 100644
--- a/src/mame/drivers/peyper.cpp
+++ b/src/mame/drivers/peyper.cpp
@@ -239,7 +239,7 @@ static INPUT_PORTS_START( pbsonic_generic )
PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_TILT ) // Tilt
PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START1 ) // Start game - Might also display next screen in "Test Mode"
PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 ) // Small coin (25 pesetas)
- PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 ) // Medium coin (50 pesetas but 100 pesetas in 'sonstwar') - never mentionned in the manuals
+ PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 ) // Medium coin (50 pesetas but 100 pesetas in 'sonstwar') - never mentioned in the manuals
PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN3 ) // Big coin (100 pesetas)
/* DSW0 : port 0x20 - DSW0-1 is bit 7 ... DSW0-8 is bit 0 */
@@ -259,7 +259,7 @@ static INPUT_PORTS_START( pbsonic_generic )
PORT_DIPNAME( 0x04, 0x00, "Balls" ) // Bolas/Partida
PORT_DIPSETTING( 0x00, "3" )
PORT_DIPSETTING( 0x04, "5" )
- PORT_DIPNAME( 0x03, 0x00, "Replay at / High-score" ) // Puntos/Premios - high-score not mentionned in some manuals - values are game specific
+ PORT_DIPNAME( 0x03, 0x00, "Replay at / High-score" ) // Puntos/Premios - high-score not mentioned in some manuals - values are game specific
PORT_DIPSETTING( 0x00, "0k 0k and 0k / 0k" )
PORT_DIPSETTING( 0x01, "0k 0k and 0k / 0k" )
PORT_DIPSETTING( 0x02, "0k 0k and 0k / 0k" )